@@ -15,14 +15,15 @@ set -o nounset
 
 # Always bring down docker services
 function cleanup() {
-    docker-services-cli down
+    eval "$(docker-services-cli down --env)"
 }
-
 trap cleanup EXIT
 
+
 python -m check_manifest --ignore ".*-requirements.txt"
 python -m sphinx.cmd.build -qnNW docs docs/_build/html
-docker-services-cli up es postgresql
+eval "$(docker-services-cli up --db ${DB:-postgresql} --search ${SEARCH:-elasticsearch} --env)"
 python -m pytest
 tests_exit_code=$?
+python -m sphinx.cmd.build -qnNW -b doctest docs docs/_build/doctest
 exit "$tests_exit_code"
